
#include <signal.h>
#include <unistd.h>
#include <string>

#include "sld.hh"

string binpath;

int main(int argc, char *argv[])
{
  SLDaemon &daemon = SLDaemon::Instance();
  SLDaemon::Options *lineopt;
  SLDaemon::Options *fileopt = NULL;

  try {
    //parse arg line options
    lineopt = daemon.getoptions(argc, argv);

    assert(lineopt);
    if (lineopt->conffile != "") {
      //parse conf file options
      fileopt = daemon.getoptions(lineopt->conffile);
    }
  }
  catch (const Error &e) {
    e.print();
    return e.code();
  }
  try {
    //apply config file option
    if (fileopt)
      daemon.applyoptions(fileopt);

    //apply parsed option
    daemon.applyoptions(lineopt);

    // register sigchild handler
    if (signal(SIGCHLD, sigchild) == SIG_ERR) {
      perror("sld: error");
      return ERR_UNKNOWN;
    }

    //execute receive command
    daemon.run();
  }
  catch (const Error &e) {
    std::cerr <<"sld: error: " << e.message() << std::endl;
    return e.code();
  }
  return ERR_UNKNOWN;
}

string getbinpath(const char *argv0) {
  // check if is absolute pathname
  if (*argv0 == '/')
    return string(argv0);

  //contatence current dir with argv0
  char buf[PATH_MAX];
  getcwd(buf, PATH_MAX);
  return (string) buf + "/" + argv0;
}
